@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2001 Marc Mutz <mutz@kde.org>
+    SPDX-FileCopyrightText: 2001 Marc Mutz <mutz@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "emailaddressrequester.h"
@@ -35,13 +22,12 @@ class Q_DECL_HIDDEN Akonadi::EmailAddressRequester::Private
 public:
     Private(EmailAddressRequester *qq)
         : q(qq)
-        , mLineEdit(nullptr)
     {
     }
 
     void slotAddressBook();
 
-    EmailAddressRequester *q = nullptr;
+    EmailAddressRequester *const q;
     KLineEdit *mLineEdit = nullptr;
 };
 
@@ -79,7 +65,7 @@ EmailAddressRequester::EmailAddressRequester(QWidget *parent)
     : QWidget(parent)
     , d(new Private(this))
 {
-    QHBoxLayout *layout = new QHBoxLayout(this);
+    auto *layout = new QHBoxLayout(this);
     layout->setSpacing(4);
     layout->setContentsMargins(0, 0, 0, 0);
 
@@ -88,7 +74,7 @@ EmailAddressRequester::EmailAddressRequester(QWidget *parent)
     d->mLineEdit->setTrapReturnKey(true);
     layout->addWidget(d->mLineEdit, 1);
 
-    QPushButton *button = new QPushButton(this);
+    auto *button = new QPushButton(this);
     button->setIcon(QIcon::fromTheme(QStringLiteral("help-contents")));
     button->setFixedHeight(d->mLineEdit->sizeHint().height());
     button->setToolTip(i18n("Open Address Book"));
