@@ -1,22 +1,9 @@
 /*
     This file is part of Contact Editor.
 
-    Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2009 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "categorieseditwidget.h"
@@ -24,9 +11,7 @@
 #include <item.h>
 #include <tag.h>
 #include <tagwidget.h>
-#include <kcontacts/addressee.h>
 #include <QHBoxLayout>
-#include <kcoreaddons_version.h>
 #include <KPluginFactory>
 
 K_PLUGIN_CLASS_WITH_JSON(CategoriesEditWidget, "categorieseditwidgetplugin.json")
@@ -34,7 +19,7 @@ K_PLUGIN_CLASS_WITH_JSON(CategoriesEditWidget, "categorieseditwidgetplugin.json"
 CategoriesEditWidget::CategoriesEditWidget(QWidget *parent, const QList<QVariant> &)
     : ContactEditor::CategoriesEditAbstractWidget(parent)
 {
-    QHBoxLayout *layout = new QHBoxLayout(this);
+    auto *layout = new QHBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
     mTagWidget = new Akonadi::TagWidget(this);
     layout->addWidget(mTagWidget);
