@@ -1,23 +1,10 @@
 /*
     This file is part of Contact Editor.
 
-    Copyright (C) 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
-    Copyright (C) 2016-2020 Laurent Montel <montel.org>
+    SPDX-FileCopyrightText: 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
+    SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "messagingwidgetlister.h"
@@ -49,7 +36,7 @@ void MessagingWidgetLister::loadContact(const KContacts::Addressee &contact)
         auto wIt = widgetList.constBegin();
         auto wEnd = widgetList.constEnd();
         for (int i = 0; wIt != wEnd; ++wIt, ++i) {
-            MessagingWidget *w = qobject_cast<MessagingWidget *>(*wIt);
+            auto *w = qobject_cast<MessagingWidget *>(*wIt);
             w->setIMAddress(imaddresses.at(i));
         }
     }
@@ -60,7 +47,7 @@ void MessagingWidgetLister::storeContact(KContacts::Addressee &contact) const
     KContacts::Impp::List imaddresses;
     const QList<QWidget *> widgetList = widgets();
     for (QWidget *widget : widgetList) {
-        MessagingWidget *w = qobject_cast<MessagingWidget *>(widget);
+        auto *w = qobject_cast<MessagingWidget *>(widget);
         imaddresses << w->imAddress();
     }
     contact.setImppList(imaddresses);
@@ -70,14 +57,14 @@ void MessagingWidgetLister::setReadOnly(bool readOnly)
 {
     const QList<QWidget *> widgetList = widgets();
     for (QWidget *widget : widgetList) {
-        MessagingWidget *w = qobject_cast<MessagingWidget *>(widget);
+        auto *w = qobject_cast<MessagingWidget *>(widget);
         w->setReadOnly(readOnly);
     }
 }
 
 QWidget *MessagingWidgetLister::createWidget(QWidget *parent)
 {
-    MessagingWidget *w = new MessagingWidget(parent);
+    auto *w = new MessagingWidget(parent);
     reconnectWidget(w);
     return w;
 }
@@ -130,7 +117,7 @@ void MessagingWidgetLister::updateAddRemoveButton()
     QList<QWidget *>::ConstIterator wIt = widgetList.constBegin();
     QList<QWidget *>::ConstIterator wEnd = widgetList.constEnd();
     for (; wIt != wEnd; ++wIt) {
-        MessagingWidget *w = qobject_cast<MessagingWidget *>(*wIt);
+        auto *w = qobject_cast<MessagingWidget *>(*wIt);
         w->updateAddRemoveButton(addButtonEnabled);
     }
 }
